This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Spelling patch: gcc/ch


This patch fixes spelling errors in gcc/ch.  Applied.

Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ch/ChangeLog,v
retrieving revision 1.130
diff -u -r1.130 ChangeLog
--- ChangeLog	2001/10/30 04:27:16	1.130
+++ ChangeLog	2001/10/31 00:57:23
@@ -1,3 +1,8 @@
+2001-10-31  Joseph S. Myers  <jsm28@cam.ac.uk>
+
+	* ChangeLog, actions.c, ch-tree.def, decl.c, except.c, inout.c,
+	tasking.c, typeck.c: Fix spelling errors.
+
 2001-10-29  Zack Weinberg  <zack@codesourcery.com>
 
 	* convert.c, inout.c, loop.c, nloop.c, tasking.c, timing.c,
@@ -864,7 +869,7 @@
 
 Thu Oct  1 10:43:45 1998  Nick Clifton  <nickc@cygnus.com>
 
-	* lex.c: Replace occurances of HANDLE_SYSV_PRAGMA with
+	* lex.c: Replace occurrences of HANDLE_SYSV_PRAGMA with
 	HANDLE_GENERIC_PRAGMAS.
 	(handle_generic_pragma): New function: Parse generic pragmas.
 
@@ -1120,7 +1125,7 @@
 
 Sat Sep  5 22:25:51 1998  Richard Henderson  <rth@cygnus.com>
 
-	* Makefile.in: Update dependancies for top-level gcc files that moved.
+	* Makefile.in: Update dependencies for top-level gcc files that moved.
 
 Sat Sep  5 02:21:08 1998  Jeffrey A Law  (law@cygnus.com)
 
@@ -1396,7 +1401,7 @@
 
 Wed Feb 18 23:48:57 1998  Richard Henderson  <rth@cygnus.com>
 
-	* Make-lang.in (cc1chill): Kill lingering bc-opcode.h dependancy.
+	* Make-lang.in (cc1chill): Kill lingering bc-opcode.h dependency.
 
 Wed Feb 18 17:35:05 1998  Dave Brolley  <brolley@cygnus.com>
 
@@ -2043,7 +2048,7 @@
 
 	* grant.c (print_integer_selective): In case of a RANGE of
 	a SET mode, try to find and grant the parent mode.
-	(grant_seized_identifier): Dont write it out, if the identifier
+	(grant_seized_identifier): Don't write it out, if the identifier
 	doesn't have a seize file (it may come from a SPEC MODULE
 	defined in the compilation unit).
 
@@ -2325,7 +2330,7 @@
 
 	* grant.c (write_spec_module): If not GRANT ALL specified,
 	write only this identifiers to grant file which are
-	neccessary to form a prober grant file. This will shorten
+	necessary to form a prober grant file. This will shorten
 	grant files and speed up compilation.
 	(decode_constant_selective, decode_mode_selective,
 	get_type_selective, decode_decl_selective,
@@ -8488,7 +8493,7 @@
 	* ch-parse.y (optprogendname, optname):  Rename to opt_end_label.
 	* ch-parse.y:  Add support for compound name strings, but defer
 	using all over teh place, due to parser ambiguities.
-	Howver, do use defining_occurrence where appropriate.
+	However, do use defining_occurrence where appropriate.
 	* ch-parse.y:  Re-write syntax and semantics of GRANT and SEIZE
 	statements to support Blue Book functionality.  Neato!
 
@@ -10526,7 +10531,7 @@
 	Now, a grantfile is a spec module and contains all the
 	top-level declarations of the granting module, not just
 	those that are granted.  It also contains explicit grant
-	statments naming those declared names that are granted.
+	statements naming those declared names that are granted.
 	It also has seize statements and use_seize_file directives
 	to correctly handle transitive dependencies.
 
@@ -11229,7 +11234,7 @@
 
 	* Makefile.in (install-libchill, install-librmt):  Removed.
 	* ch-actions.c (build_chill_exception_decl):  Change decl
-	to initialized char array, rather than unitialized common.
+	to initialized char array, rather than uninitialized common.
 	(Simplifies extracting string name of exception.)
 	* ch-actions.c:  Adjust interface to cause_exception accordingly.
 	* ch-typeck.c (build_chill_array_ref):  Cause rangefail if
Index: actions.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ch/actions.c,v
retrieving revision 1.20
diff -u -r1.20 actions.c
--- actions.c	2001/06/10 13:47:57	1.20
+++ actions.c	2001/10/31 00:57:24
@@ -1749,7 +1749,7 @@
   			    NULL_TREE)))))))));
     }
 
-  /* The following is probably superceded by the
+  /* The following is probably superseded by the
      above code for SET_IN_EXPR. FIXME! */
   else if (TREE_CODE (lhs) == BIT_FIELD_REF)
     {
Index: ch-tree.def
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ch/ch-tree.def,v
retrieving revision 1.3
diff -u -r1.3 ch-tree.def
--- ch-tree.def	1999/01/11 13:17:13	1.3
+++ ch-tree.def	2001/10/31 00:57:24
@@ -35,7 +35,7 @@
 
 /* A 'SEIZE (OLD->NEW)!POSTFIX' or 'GRANT (OLD->NEW)!POSTFIX' is
    represented as an ALIAS_DECL where DECL_OLD_PREFIX, DECL_NEW_PREFIX,
-   and DECL_POSTFIX points to OLD, NEW, and POSTFIX, repectively.
+   and DECL_POSTFIX points to OLD, NEW, and POSTFIX, respectively.
    These are IDENTIFIER_NODEs, or NULL if empty.
    DECL_NAME is NEW!POSTFIX.  After binding, DECL_ABSTRACT_ORIGIN
    (if not an error_mark) points to a decl whose DECL_NAME is OLD!POSTFIX.
Index: decl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ch/decl.c,v
retrieving revision 1.32
diff -u -r1.32 decl.c
--- decl.c	2001/06/10 13:47:57	1.32
+++ decl.c	2001/10/31 00:57:25
@@ -4475,7 +4475,7 @@
     }
 
   /* Fix all error_mark_nodes in enum. Increment maxnode and assign value.
-     This is neccessary to make a duplicate value check in the enum */
+     This is necessary to make a duplicate value check in the enum */
   for (pair = values; pair; pair = TREE_CHAIN (pair))
     {
       tree decl = TREE_VALUE (pair);
Index: except.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ch/except.c,v
retrieving revision 1.16
diff -u -r1.16 except.c
--- except.c	2001/02/04 23:18:43	1.16
+++ except.c	2001/10/31 00:57:25
@@ -130,7 +130,7 @@
 static tree jbuf_ident, prev_ident, handlers_ident;
 static tree exception_stack_decl = 0;
 
-/* Chain of cleanups assocated with exception handlers.
+/* Chain of cleanups associated with exception handlers.
    The TREE_PURPOSE is an INTEGER_CST whose value is the
    DECL_ACTION_NESTING_LEVEL (when the handled actions was entered).
    The TREE_VALUE is an expression to expand when we exit that action. */
Index: inout.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ch/inout.c,v
retrieving revision 1.16
diff -u -r1.16 inout.c
--- inout.c	2001/10/30 04:27:16	1.16
+++ inout.c	2001/10/31 00:57:26
@@ -4577,7 +4577,7 @@
   return build1 (CONVERT_EXPR, void_type_node, integer_zero_node);
 }
 
-/* this function build all neccesary enum-tables used for
+/* this function build all necessary enum-tables used for
    WRITETEXT or READTEXT of an enum */
 
 void build_enum_tables ()
Index: typeck.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ch/typeck.c,v
retrieving revision 1.27
diff -u -r1.27 typeck.c
--- typeck.c	2001/10/30 04:27:17	1.27
+++ typeck.c	2001/10/31 00:57:28
@@ -570,7 +570,7 @@
   if (! integer_zerop (TYPE_MIN_VALUE (domain)))
     {
       /* The C part of the compiler doesn't understand how to do
-	 arithmetic with dissimilar enum types.  So we check compatability
+	 arithmetic with dissimilar enum types.  So we check compatibility
 	 here, and perform the math in INTEGER_TYPE.  */
       if (TREE_CODE (TREE_TYPE (idx)) == ENUMERAL_TYPE
 	  && chill_comptypes (TREE_TYPE (idx), domain, 0))
@@ -1114,7 +1114,7 @@
   if (expr_type_is_discrete && type_is_discrete)
     {
       /* do an overflow check
-	 FIXME: is this always neccessary ??? */
+	 FIXME: is this always necessary ??? */
       /* FIXME: don't do range chacking when target type is PTR.
 	 PTR doesn't have MIN and MAXVALUE. result is sigsegv. */
       if (range_checking && type != ptr_type_node)

Index: tasking.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ch/tasking.c,v
retrieving revision 1.17
diff -u -r1.17 tasking.c
--- tasking.c	2001/10/30 04:27:17	1.17
+++ tasking.c	2001/10/31 00:57:27
@@ -1959,7 +1959,7 @@
 
   if (TREE_CHAIN (loclist) != NULL_TREE)
     {
-      error ("buffer receive alternative requires only 1 defining occurence.");
+      error ("buffer receive alternative requires only 1 defining occurrence.");
       return error_mark_node;
     }
 
@@ -1969,7 +1969,7 @@
 
       /* here we change the mode of rc_state->sig_code to
 	 REF ARRAY (0:65535) REF __tmp_DESCR_type.
-	 This is neccesary, cause we cannot evaluate the buffer twice
+	 This is necessary, cause we cannot evaluate the buffer twice
 	 (once here where we compare against the address of the buffer
 	 and second in build_receive_buffer_case_end, where we use the
 	 address build the descriptor, which gets passed to __wait_buffer).
@@ -2046,7 +2046,7 @@
 
   if (! CH_LOCATION_P (var))
     {
-      error ("defining occurence in receive buffer alternative must be a location.");
+      error ("defining occurrence in receive buffer alternative must be a location.");
       had_errors = 1;
     }
 
@@ -2097,7 +2097,7 @@
  * LABEL_CNT is the case-label counter passed from build_receive_case_start.
  * ELSE_CLAUSE defines if the RECEIVE CASE action had an ELSE(1) or not(0).
  * BUF_LIST is a tree-list of tree-lists, where TREE_VALUE defines the 
  * BUFFER location and TREE_PURPOSE defines the defining occurence.
  */
 static void
 build_receive_buffer_case_end (buf_list, else_clause)
@@ -2097,7 +2097,7 @@
  * ELSE_CLAUSE defines if the RECEIVE CASE action had an ELSE(1) or not(0).
  * BUF_LIST is a tree-list of tree-lists, where TREE_VALUE defines the 
- * BUFFER location and TREE_PURPOSE defines the defining occurence.
+ * BUFFER location and TREE_PURPOSE defines the defining occurrence.
  */
 static void
-- 
Joseph S. Myers
jsm28@cam.ac.uk


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]